import docgenerator

def main():
    docgenerator.run()